@@ -1028,7 +1028,7 @@ namespace KDirStat
      **/
     class KAnyDirReadJob: public TQObject, public KDirReadJob
     {
-	Q_OBJECT
+	TQ_OBJECT
   
 
     public:
@@ -1099,7 +1099,7 @@ namespace KDirStat
      **/
     class KDirTree: public TQObject
     {
-	Q_OBJECT
+	TQ_OBJECT
   
 
     public:
